MJOLNIR
============
Neutron scattering software to be used at CAMEA-like Neutron Instruments.

## Installation
This package is to be install through the Python Package Manager by issuing 

```shell
pip install MJOLNIR
```

For full documentation see http://mjolnir.readthedocs.io/en/latest/ or https://www.psi.ch/en/sinq/camea/data-treatment. 

